package com.ruoyi.asset.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.asset.mapper.TbAssetAdjustmentMapper;
import com.ruoyi.asset.domain.TbAssetAdjustment;
import com.ruoyi.asset.service.ITbAssetAdjustmentService;

/**
 * 资产调整Service业务层处理
 * 
 * @author yuandongli
 * @date 2023-05-15
 */
@Service
public class TbAssetAdjustmentServiceImpl implements ITbAssetAdjustmentService 
{
    @Autowired
    private TbAssetAdjustmentMapper tbAssetAdjustmentMapper;

    /**
     * 查询资产调整
     * 
     * @param id 资产调整主键
     * @return 资产调整
     */
    @Override
    public TbAssetAdjustment selectTbAssetAdjustmentById(Long id)
    {
        return tbAssetAdjustmentMapper.selectTbAssetAdjustmentById(id);
    }

    /**
     * 查询资产调整列表
     * 
     * @param tbAssetAdjustment 资产调整
     * @return 资产调整
     */
    @Override
    public List<TbAssetAdjustment> selectTbAssetAdjustmentList(TbAssetAdjustment tbAssetAdjustment)
    {
        return tbAssetAdjustmentMapper.selectTbAssetAdjustmentList(tbAssetAdjustment);
    }

    /**
     * 新增资产调整
     * 
     * @param tbAssetAdjustment 资产调整
     * @return 结果
     */
    @Override
    public int insertTbAssetAdjustment(TbAssetAdjustment tbAssetAdjustment)
    {
        return tbAssetAdjustmentMapper.insertTbAssetAdjustment(tbAssetAdjustment);
    }

    /**
     * 修改资产调整
     * 
     * @param tbAssetAdjustment 资产调整
     * @return 结果
     */
    @Override
    public int updateTbAssetAdjustment(TbAssetAdjustment tbAssetAdjustment)
    {
        return tbAssetAdjustmentMapper.updateTbAssetAdjustment(tbAssetAdjustment);
    }

    /**
     * 批量删除资产调整
     * 
     * @param ids 需要删除的资产调整主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetAdjustmentByIds(Long[] ids)
    {
        return tbAssetAdjustmentMapper.deleteTbAssetAdjustmentByIds(ids);
    }

    /**
     * 删除资产调整信息
     * 
     * @param id 资产调整主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetAdjustmentById(Long id)
    {
        return tbAssetAdjustmentMapper.deleteTbAssetAdjustmentById(id);
    }
}
