package com.ruoyi.asset.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.hutool.json.JSONUtil;
import com.ruoyi.asset.domain.TbAssetInformation;
import com.ruoyi.asset.mapper.TbAssetInformationMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAssetAdjustment;
import com.ruoyi.asset.service.ITbAssetAdjustmentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产调整Controller
 * 
 * @author yuandongli
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/asset/adjustment")
public class TbAssetAdjustmentController extends BaseController
{
    @Autowired
    private ITbAssetAdjustmentService tbAssetAdjustmentService;

    @Resource
    private TbAssetInformationMapper tbAssetInformationMapper;

    /**
     * 查询资产调整列表
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetAdjustment tbAssetAdjustment)
    {
        startPage();
        List<TbAssetAdjustment> list = tbAssetAdjustmentService.selectTbAssetAdjustmentList(tbAssetAdjustment);
        return getDataTable(list);
    }

    /**
     * 导出资产调整列表
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:export')")
    @Log(title = "资产调整", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetAdjustment tbAssetAdjustment)
    {
        List<TbAssetAdjustment> list = tbAssetAdjustmentService.selectTbAssetAdjustmentList(tbAssetAdjustment);
        ExcelUtil<TbAssetAdjustment> util = new ExcelUtil<TbAssetAdjustment>(TbAssetAdjustment.class);
        util.exportExcel(response, list, "资产调整数据");
    }

    /**
     * 获取资产调整详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetAdjustmentService.selectTbAssetAdjustmentById(id));
    }

    /**
     * 新增资产调整
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:add')")
    @Log(title = "资产调整", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetAdjustment tbAssetAdjustment)
    {
        String assetNumber = tbAssetAdjustment.getAssetNumber();
        TbAssetInformation tbAssetInformation = tbAssetInformationMapper.selectTbAssetInformationByAssetNumber(assetNumber);
        String jsonStr = JSONUtil.toJsonStr(tbAssetInformation);
        tbAssetAdjustment.setOriginalAssetInfo(jsonStr);

        return toAjax(tbAssetAdjustmentService.insertTbAssetAdjustment(tbAssetAdjustment));
    }

    /**
     * 提交资产调整
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:submit')")
    @Log(title = "资产调整提交", businessType = BusinessType.UPDATE)
    @PutMapping("/submit")
    public AjaxResult submit(@RequestBody TbAssetAdjustment tbAssetAdjustment)
    {
        tbAssetAdjustment.setRecordStatus(1L);
        return toAjax(tbAssetAdjustmentService.updateTbAssetAdjustment(tbAssetAdjustment));
    }

    /**
     * 审核资产调整
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:audit')")
    @Log(title = "资产调整审核", businessType = BusinessType.UPDATE)
    @PutMapping("/audit")
    public AjaxResult audit(@RequestBody TbAssetAdjustment tbAssetAdjustment)
    {
        tbAssetAdjustment.setRecordStatus(2L);
        return toAjax(tbAssetAdjustmentService.updateTbAssetAdjustment(tbAssetAdjustment));
    }

    /**
     * 修改资产调整
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:edit')")
    @Log(title = "资产调整", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetAdjustment tbAssetAdjustment)
    {
        return toAjax(tbAssetAdjustmentService.updateTbAssetAdjustment(tbAssetAdjustment));
    }

    /**
     * 删除资产调整
     */
    @PreAuthorize("@ss.hasPermi('asset:adjustment:remove')")
    @Log(title = "资产调整", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetAdjustmentService.deleteTbAssetAdjustmentByIds(ids));
    }
}
